@@ -3,22 +3,30 @@
 """Lookup and instantiate classes with style."""
 
 from .api import (
+    ClassResolver,
+    KeywordArgumentError,
+    Resolver,
+    UnexpectedKeywordError,
+    get_cls,
+)
+from .base import (
+    RegistrationError,
+    RegistrationNameConflict,
+    RegistrationSynonymConflict,
+)
+from .func import FunctionResolver
+from .utils import (
     Hint,
     HintOrType,
     HintType,
     InstOrType,
-    KeywordArgumentError,
     Lookup,
     LookupOrType,
     LookupType,
     OptionalKwargs,
-    Resolver,
-    UnexpectedKeywordError,
-    get_cls,
     get_subclasses,
     normalize_string,
 )
-from .func import FunctionResolver
 
 __all__ = [
     # Type Hints
@@ -32,12 +40,16 @@ __all__ = [
     "OptionalKwargs",
     # Classes
     "Resolver",
+    "ClassResolver",
     "FunctionResolver",
     # Utilities
     "get_cls",
     "get_subclasses",
     "normalize_string",
     # Exceptions
+    "RegistrationError",
+    "RegistrationNameConflict",
+    "RegistrationSynonymConflict",
     "KeywordArgumentError",
     "UnexpectedKeywordError",
 ]
